<?php

namespace CADSUP\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;

class RegiaoService {

    protected $connection;
    protected $cadSupUtil;
    
    public function __construct($entityManager, $environment, $cadSupUtil){
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
        $this->cadSupUtil = $cadSupUtil;
    }
    
    public function deleteRegiao ($row){

		$param = array();
        $param['P_CDREGIAO'] = $row['CDREGIAO'];
        $query = "DELETE REGIAO WHERE CDREGIAO = :P_CDREGIAO";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function deleteFilial ($row){
    	
    	$param = array();
        $param['P_CDREGIAO'] = $row['CDREGIAO'];
    	$query = "UPDATE FILIAL SET CDREGIAO = null WHERE CDREGIAO = :P_CDREGIAO";
		try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function deleteMunicipio ($row){
    	
    	$param = array();
        $param['P_CDREGIAO'] = $row['CDREGIAO'];
    	$query = "UPDATE MUNICIPIO SET CDREGIAO = '' WHERE CDREGIAO = :P_CDREGIAO";
		try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function insertMunicipio ($row){
    	
    	$param = array();
        $param['P_CDREGIAO'] = $row['CDREGIAO'];
        $param['P_CDPAIS']   = $row['CDPAIS'];
        $param['P_SGESTADO'] = $row['SGESTADO'];
        $param['P_CDMUNICIPIO'] = $row['CDMUNICIPIO'];
        
        
    	$query = "UPDATE MUNICIPIO SET CDREGIAO = :P_CDREGIAO WHERE CDPAIS = :P_CDPAIS AND SGESTADO = :P_SGESTADO AND CDMUNICIPIO = :P_CDMUNICIPIO";
		try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    
    public function verificaFilial ($row){
    	
    	$param = array();
        $param['P_CDREGIAO'] = $row['CDREGIAO'];
        $this->connection->beginTransaction();
        $codUnidade = $this->cadSupUtil->criarListaValores($row['CDFILIAL']);
        $row['CDFILIAL'] = "_NRLISTA=".$codUnidade ;
        $param['P_CDFILIAL'] = $row['CDFILIAL'];
        $param['P_TCDREGIAO'] = $row['TCDREGIAO'];
        
    
		$query = "SELECT FILIAL.CDREGIAO, FILIAL.CDFILIAL, FILIAL.NMFILIAL, REGIAO.NMREGIAO FROM REGIAO RIGHT JOIN FILIAL ON FILIAL.CDREGIAO = REGIAO.CDREGIAO WHERE ( VALOR_NA_LISTA(FILIAL.CDFILIAL, :P_CDFILIAL) <> 0 ) AND ( FILIAL.CDREGIAO = :P_CDREGIAO OR :P_TCDREGIAO = 'T' )";
		try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            $retorno = $std->fetchAll();
            $this->cadSupUtil->deleteLista($codUnidade);
            $this->connection->commit();
            return $retorno;
        } catch (Exception $e){
            $this->connection->rollback();
            throw $e;
        }
    }
    
    public function cadastraUnidadeNaRegiao($row) {
        
        $this->connection->beginTransaction();
        $codUnidade = $this->cadSupUtil->criarListaValores($row['CDFILIAL']);
        $row['CDFILIAL'] = "_NRLISTA=".$codUnidade ;
        

        $row['NRORG'] = $this->environment->getNrOrg();
        
        $param = array(
            'P_CDREGIAO' => $row['CDREGIAO'],
            'P_CDFILIAL' => $row['CDFILIAL'],
            'P_NRORG' => $row['NRORG']

        );
    
        $query = "UPDATE 
                        FILIAL
                    SET
                        CDREGIAO = :P_CDREGIAO
                    WHERE
                        (VALOR_NA_LISTA(FILIAL.CDFILIAL, :P_CDFILIAL) <> 0)
                    AND (NRORG = :P_NRORG)";
    
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            $this->cadSupUtil->deleteLista($codUnidade);
            $this->connection->commit();
        } catch (Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    
    public function deleteUnidade($cdfilial){
    	
    	$this->connection->beginTransaction();
        $codUnidade = $this->cadSupUtil->criarListaValores($cdfilial);
        $row['CDFILIAL'] = "_NRLISTA=".$codUnidade ;
        
        $param = array(
            'P_CDFILIAL' => $row['CDFILIAL']
        );
        
    	$query = "UPDATE FILIAL SET CDREGIAO = null WHERE (VALOR_NA_LISTA(FILIAL.CDFILIAL, :P_CDFILIAL) <> 0)";
		try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            $this->cadSupUtil->deleteLista($codUnidade);
            $this->connection->commit();
        } catch (Exception $e){
            $this->connection->rollback();
            throw $e;
        }
    }
}