<?php
namespace CADSUP\Util;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;

class Util {
	
    protected $crudService;
    protected $newCode;
    protected $environment;
	protected $dataSourceManager;
	protected $connection;
    const TABLE_LISTA = "LISTA";

	public function __construct($crudService, $newCode, $environment, $dataSourceManager, $entityManager) {
        $this->crudService = $crudService;

        $this->newCode = $newCode;
        $this->environment = $environment;
		$this->dataSourceManager = $dataSourceManager;
		$this->connection = $entityManager->getConnection();
	}

    public function validateDuplicatedRecords($row, $dataSourceName, $columns) {
        $conditions = array();
        foreach ($columns as $column) {
            array_push($conditions, array(
                "columnName" => $column,
                "operator"   => '=',
                "value"      => $row[$column]
            ));
        }
        $dataSet = $this->crudService->getFilteredDataSet($dataSourceName, $conditions);

        if (!empty($dataSet->getRows())) {
            throw new \Exception("registerExists", 1);
        }
    }

    public function insertLista($cdlistaArray) {
        $dataSourceName = strtolower(self::TABLE_LISTA);
        $nrlista = $this->newCode->getCodeByTableName(self::TABLE_LISTA, $this->environment->getNrOrg());
        $rows = array();
        foreach ($cdlistaArray as $cdlista) {
            $row = array(
                "NRLISTA" => $nrlista,
                "CDLISTA" => $cdlista,
                "__is_new" => true
            );
            array_push($rows, $row);
        }
        $dataSet = new DataSet($dataSourceName, $rows);
        $request = new DTO\Request\DataSet($dataSet, "", "", "");
        $rowsToSave = $this->crudService->getRowsToSave($request, $dataSourceName);
        $this->crudService->save($dataSourceName, $rowsToSave);
        return $nrlista;
    }
    
    public function deleteLista($nrlista) {
        $dataSourceName = strtolower(self::TABLE_LISTA);
        $conditions = array(
            array(
                "columnName" => "NRLISTA",
                "operator"   => '=',
                "value"      => $nrlista
            )
        );
        $dataSet = $this->crudService->getFilteredDataSet($dataSourceName, $conditions);
        $this->dataSourceManager->delete($dataSet);
    }
    
    public function insertList($nrlista, $cdlista) {
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $cdlista
        );

        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function criarListaValores($lista){
        $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrOrg());
        $valores = explode('_',$lista);
        try{
            foreach($valores as $key){
                $this->insertList($nrlista, $key);
            }
            return $nrlista;
        } catch(\Exception $e){
            throw $e;
        }
     }
    
    
}